@@ -15,6 +15,7 @@ cobib add --bibtex some_biblatex_file.bib
 cobib add --arxiv <some arXiv ID>
 cobib add --doi <some DOI>
 cobib add --isbn <some ISBN>
+cobib add --url <some URL>
 cobib add --yaml some_cobib_style_yaml_file.yaml
 ```
 
@@ -64,6 +65,21 @@ If you want to manually suppress the automatic download, specify the `--skip-dow
 cobib add --skip-download --arxiv <some arXiv ID>
 ```
 
+Since v3.3.0 you can also update existing entries by using the `--update` argument:
+```
+cobib add --doi <some DOI> --update --label <some existing label>
+```
+This will take the existing entry and combine it with all new information found in the freshly added
+entry. Existing fields will be overwritten. If you have an automatically downloaded file associated
+with this entry, that will also be overwritten.
+This feature is especially useful if you want to update an entry which you previously added from the
+arXiv with its newly published version.
+
+If you don't specify `--update` and run into a situation where the label which you are trying to add
+already exists, coBib will disambiguate it based on the `config.database.format.label_suffix`
+setting. It defaults to appending `_a`, `_b`, etc.
+You can disable this disambiguation by passing `--skip-existing` to the add command.
+
 ### TUI
 
 You can also trigger this command from the `cobib.tui.tui.TUI`.
@@ -84,13 +100,14 @@ from collections import OrderedDict
 from typing import IO, TYPE_CHECKING, Any, Dict, List
 
 from cobib import parsers
-from cobib.config import config
+from cobib.config import Event, config
 from cobib.database import Database, Entry
 from cobib.utils.file_downloader import FileDownloader
 from cobib.utils.journal_abbreviations import JournalAbbreviations
 
 from .base_command import ArgumentParser, Command
 from .edit import EditCommand
+from .modify import evaluate_as_f_string
 
 LOGGER = logging.getLogger(__name__)
 
@@ -103,7 +120,7 @@ class AddCommand(Command):
 
     name = "add"
 
-    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-branches,too-many-statements
     def execute(self, args: List[str], out: IO[Any] = sys.stdout) -> None:
         """Adds a new entry.
 
@@ -117,11 +134,14 @@ class AddCommand(Command):
             args: a sequence of additional arguments used for the execution. The following values
                 are allowed for this command:
                     * `-l`, `--label`: the label to give to the new entry.
+                    * `-u`, `--update`: updates an existing database entry if it already exists.
                     * `-f`, `--file`: one or multiple files to associate with this entry. This data
                       will be stored in the `cobib.database.Entry.file` property.
                     * `-p`, `--path`: the path to store the downloaded associated file in. This can
                       be used to overwrite the `config.utils.file_downloader.default_location`.
-                    * `-s`, `--skip-download`: skips the automatic download of an associated file.
+                    * `--skip-download`: skips the automatic download of an associated file.
+                    * `--skip-existing`: skips entry if label exists instead of running label
+                      disambiguation.
                     * in addition to the options above, a *mutually exclusive group* of keyword
                       arguments for all available `cobib.parsers` are registered at runtime. Please
                       check the output of `cobib add --help` for the exact list.
@@ -133,6 +153,12 @@ class AddCommand(Command):
         LOGGER.debug("Starting Add command.")
         parser = ArgumentParser(prog="add", description="Add subcommand parser.")
         parser.add_argument("-l", "--label", type=str, help="the label for the new database entry")
+        parser.add_argument(
+            "-u",
+            "--update",
+            action="store_true",
+            help="update an entry if the label exists already",
+        )
         file_action = "extend" if sys.version_info[1] >= 8 else "append"
         parser.add_argument(
             "-f",
@@ -144,19 +170,29 @@ class AddCommand(Command):
         )
         parser.add_argument("-p", "--path", type=str, help="the path for the associated file")
         parser.add_argument(
-            "-s",
             "--skip-download",
             action="store_true",
             help="skip the automatic download of an associated file",
         )
+        parser.add_argument(
+            "--skip-existing",
+            action="store_true",
+            help="skips entry addition if existent instead of using label disambiguation",
+        )
         group_add = parser.add_mutually_exclusive_group()
         avail_parsers = {
             cls.name: cls for _, cls in inspect.getmembers(parsers) if inspect.isclass(cls)
         }
         for name in avail_parsers.keys():
-            group_add.add_argument(
-                f"-{name[0]}", f"--{name}", type=str, help=f"{name} object identfier"
-            )
+            try:
+                group_add.add_argument(
+                    f"-{name[0]}", f"--{name}", type=str, help=f"{name} object identfier"
+                )
+            except argparse.ArgumentError:
+                try:
+                    group_add.add_argument(f"--{name}", type=str, help=f"{name} object identfier")
+                except argparse.ArgumentError:
+                    continue
         parser.add_argument(
             "tags",
             nargs=argparse.REMAINDER,
@@ -173,6 +209,8 @@ class AddCommand(Command):
             LOGGER.error(exc.message)
             return
 
+        Event.PreAddCommand.fire(largs)
+
         new_entries: Dict[str, Entry] = OrderedDict()
 
         edit_entries = False
@@ -204,6 +242,15 @@ class AddCommand(Command):
                 # logging done by cobib/database/entry.py
                 value.label = largs.label
             new_entries = OrderedDict((largs.label, value) for value in new_entries.values())
+        else:
+            formatted_entries = OrderedDict()
+            for label, value in new_entries.items():
+                formatted_label = evaluate_as_f_string(
+                    config.database.format.label_default, {"label": label, **value.data.copy()}
+                )
+                value.label = formatted_label
+                formatted_entries[formatted_label] = value
+            new_entries = formatted_entries
 
         if largs.file is not None:
             if file_action == "append":
@@ -229,27 +276,44 @@ class AddCommand(Command):
         for lbl, entry in new_entries.copy().items():
             # check if label already exists
             if lbl in existing_labels:
-                msg = (
-                    f"You tried to add a new entry '{lbl}' which already exists!"
-                    f"\nPlease use `cobib edit {lbl}` instead!"
-                )
-                LOGGER.warning(msg)
-                new_entries.pop(lbl)
-                continue
+                if not largs.update:
+                    msg = f"You tried to add a new entry '{lbl}' which already exists!"
+                    LOGGER.warning(msg)
+                    if edit_entries or largs.skip_existing:
+                        msg = f"Please use `cobib edit {lbl}` instead!"
+                        LOGGER.warning(msg)
+                        continue
+                    msg = (
+                        "The label will be disambiguated based on the configuration option: "
+                        "config.database.format.label_suffix"
+                    )
+                    LOGGER.warning(msg)
+                    new_label = bib.disambiguate_label(lbl, entry)
+                    entry.label = new_label
+                    new_entries[new_label] = entry
+                    new_entries.pop(lbl)
+                else:
+                    # label exists but the user asked to update an existing entry
+                    existing_data = bib[lbl].data.copy()
+                    existing_data.update(entry.data)
+                    entry.data = existing_data.copy()
             # download associated file (if requested)
             if "_download" in entry.data.keys():
                 if largs.skip_download:
                     entry.data.pop("_download")
                 else:
-                    path = FileDownloader().download(entry.data.pop("_download"), lbl, largs.path)
+                    path = FileDownloader().download(
+                        entry.data.pop("_download"), lbl, folder=largs.path, overwrite=largs.update
+                    )
                     if path is not None:
                         entry.data["file"] = str(path)
             # check journal abbreviation
             if "journal" in entry.data.keys():
                 entry.data["journal"] = JournalAbbreviations.elongate(entry.data["journal"])
 
-        bib.update(new_entries)
+        Event.PostAddCommand.fire(new_entries)
 
+        bib.update(new_entries)
         if edit_entries:
             EditCommand().execute([largs.label])
 
