@@ -37,7 +37,7 @@ import tempfile
 from pathlib import Path
 from typing import IO, TYPE_CHECKING, Any, List
 
-from cobib.config import config
+from cobib.config import Event, config
 from cobib.database import Database, Entry
 from cobib.parsers.yaml import YAMLParser
 from cobib.utils.rel_path import RelPath
@@ -95,6 +95,8 @@ class EditCommand(Command):
             LOGGER.error(exc.message)
             return
 
+        Event.PreEditCommand.fire(largs)
+
         yml = YAMLParser()
 
         bib = Database()
@@ -162,6 +164,8 @@ class EditCommand(Command):
                             continue
                     new_files.append(file)
                 new_entry.file = new_files
+
+        Event.PostEditCommand.fire(new_entry)
         bib.save()
 
         self.git(args=vars(largs))
